ArgSettings

Enum ArgSettings 

pub enum ArgSettings {
Show 18 variants Required, MultipleValues, MultipleOccurrences, AllowEmptyValues, Hidden, TakesValue, UseValueDelimiter, NextLineHelp, RequireDelimiter, HidePossibleValues, AllowHyphenValues, RequireEquals, Last, HideDefaultValue, IgnoreCase, HideEnvValues, HiddenShortHelp, HiddenLongHelp, // some variants omitted
}
Various settings that apply to arguments and may be set, unset, and checked via getter/setter methods Arg::setting, Arg::unset_setting, and Arg::is_set. This is what the Arg methods which accept a bool use internally.

Variants



Required

Specifies that an arg must be used



MultipleValues

Allows an arg to accept multiple values



MultipleOccurrences

Allows an arg to appear multiple times



AllowEmptyValues

Allows an arg accept empty values such as ""



Hidden

Hides an arg from the help message



TakesValue

Allows an argument to take a value (such as --option value)



UseValueDelimiter

Enables a delimiter to break up arguments --option val1,val2,val3 becomes three values (val1, val2, and val3) instead of the default one (val1,val2,val3)



NextLineHelp

Tells an arg to display it’s help on the line below the arg itself in the help message



RequireDelimiter

Says that arg must use a delimiter to separate values



HidePossibleValues

Hides the possible values from the help message



AllowHyphenValues

Allows values that start with a hyphen



RequireEquals

Requires that an equals be used to provide a value to an option such as --option=value



Last

Says that a positional arg will be the last positional, and reuqires -- to be accessed. It can also be accessed early (i.e. before other positionals) by providing --



HideDefaultValue

Hides the default value from the help message



IgnoreCase

Possible values become case insensitive



HideEnvValues

Hides any values currently assigned to ENV variables in the help message (good for sensitive information)



HiddenShortHelp

The argument should not be shown in short help text



HiddenLongHelp

The argument should not be shown in long help text