pub struct Error {
pub cause: String,
pub message: String,
pub kind: ErrorKind,
pub info: Option<Vec<String>>,
}Expand description
Command Line Argument Parser Error
Fields
cause: StringThe cause of the error
message: StringFormatted error message, enhancing the cause message with extra information
kind: ErrorKindThe type of error
info: Option<Vec<String>>Any additional information passed along, such as the argument name that caused the error
Implementations
Sourceimpl Error
impl Error
Sourcepub fn use_stderr(&self) -> bool
pub fn use_stderr(&self) -> bool
Should the message be written to stdout or not
Sourcepub fn with_description(description: impl Into<String>, kind: ErrorKind) -> Self
pub fn with_description(description: impl Into<String>, kind: ErrorKind) -> Self
Create an error with a custom description.
This can be used in combination with Error::exit to exit your program
with a custom error message.